#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit tests

Summary:	Self-service finite-state machines for the programmer on the go
Summary(pl.UTF-8):	Bezobsługowe automaty skończone dla programisty w biegu
Name:		python3-automat
Version:	24.8.1
Release:	2
License:	MIT
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/automat/
Source0:	https://files.pythonhosted.org/packages/source/a/automat/automat-%{version}.tar.gz
# Source0-md5:	c023f8848366053a76f99cffba3ea34e
Patch0:		no-git.patch
URL:		https://pypi.org/project/Automat/
BuildRequires:	python3-modules >= 1:3.8
BuildRequires:	python3-build
BuildRequires:	python3-installer
BuildRequires:	python3-setuptools >= 1:35.0.2
BuildRequires:	python3-setuptools_scm
BuildRequires:	python3-wheel >= 0.29.0
%if %{with tests}
BuildRequires:	python3-attrs >= 19.2.0
BuildRequires:	python3-graphviz >= 0.5.2
BuildRequires:	python3-pytest
BuildRequires:	python3-twisted >= 16.1.1
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 2.044
%if %{with doc}
BuildRequires:	python3-pydoctor
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	sphinx-pdg-3
%endif
Requires:	python3-modules >= 1:3.8
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Automat is a library for concise, idiomatic Python expression of
finite-state automata (particularly deterministic finite-state
transducers).

%description -l pl.UTF-8
Automat to biblioteka do zwięzłego wyrażania automatów skończonych (w
szczególności deterministycznych automatów skończończonych z wyjściem,
tj. transduktorów) w Pythonie.

%package apidocs
Summary:	API documentation for Python automat module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona automat
Group:		Documentation

%description apidocs
API documentation for Python automat module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona automat.

%prep
%setup -q -n automat-%{version}
%patch -P0 -p1

%{__sed} -i -e 's/@@VERSION@@/%{version}/' docs/conf.py

%build
%py3_build_pyproject

%if %{with tests}
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python3} -m pytest automat/_test
%endif

%if %{with doc}
%{__python3} -m zipfile -e build-3/*.whl build-3-doc
PYTHONPATH=$(pwd)/build-3-doc \
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install_pyproject

%{__mv} $RPM_BUILD_ROOT%{_bindir}/automat-visualize{,-3}
ln -sf automat-visualize-3 $RPM_BUILD_ROOT%{_bindir}/automat-visualize
install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-automat-%{version}
cp -p docs/examples/*.py $RPM_BUILD_ROOT%{_examplesdir}/python3-automat-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc LICENSE README.md
%attr(755,root,root) %{_bindir}/automat-visualize
%attr(755,root,root) %{_bindir}/automat-visualize-3
%{py3_sitescriptdir}/automat
%{py3_sitescriptdir}/automat-%{version}.dist-info
%{_examplesdir}/python3-automat-%{version}

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_images,_static,*.html,*.js}
%endif
%changelog
* Sat May 31 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-automat.git;a=log;h=master

* Sat May 31 2025 Jakub Bogusz <qboosh@pld-linux.org> 222fc1f
- release 2 (fix python-modules dependency)

* Sat May 31 2025 Jakub Bogusz <qboosh@pld-linux.org> 7015af0
- updated dependencies

* Sat May 31 2025 Jakub Bogusz <qboosh@pld-linux.org> 5305c1a
- dist-info is lower case now

* Tue Apr 08 2025 Jan Rękorajski <baggins@pld-linux.org> f47af50
- up to 24.8.1

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 352ebdf
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> bd3d999
- python 3.13 rebuild

* Sun Jan 01 2023 Jakub Bogusz <qboosh@pld-linux.org> 98ed6cb
- python2 note

* Wed Apr 27 2022 Jakub Bogusz <qboosh@pld-linux.org> 8d4d900
- updated test dependencies
- switched docs to python3 (Makefile uses `python -m sphinx` by default)

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> bc7b4f1
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 48196db
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 05635ef
- rebuild with python 3.10

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 0a3fb8b
- release 2 (by relup.sh)

* Sun Mar 22 2020 Jakub Bogusz <qboosh@pld-linux.org> 8d69f9e
- tests BC: python-PyXML

* Sat Mar 21 2020 Jakub Bogusz <qboosh@pld-linux.org> ed9196a
- cleanup

* Sat Mar 21 2020 Jakub Bogusz <qboosh@pld-linux.org> d26ecac
- new

